Rucio Database Schema
=====================

This figure describes the database schema including the relationships between the tables, the available 
indexes and primary keys, and the identifiers tracked by the database. 


.. image:: images/rucio_schema.png
   :scale: 80 %
   :alt: Figure 1
   :align: center
